@@ -4,11 +4,16 @@
 from __future__ import (division, print_function, absolute_import,
                         unicode_literals)
 
-__all__ = ["API", "KOI", "Planet", "Dataset"]
+__all__ = ["API", "KOI", "Planet"]
 
 import os
+import re
 import logging
-import requests
+
+try:
+    import requests
+except ImportError:
+    requests = None
 
 
 # Root directory for local data.
@@ -25,6 +30,11 @@ class API(object):
 
     base_url = "http://archive.stsci.edu/kepler/{0}/search.php"
 
+    def __init__(self):
+        if not requests:
+            raise ImportError("The requests module is required to interface "
+                              "with the MAST API.")
+
     def request(self, category, **params):
         """
         Submit a request to the API and return the JSON response.
@@ -71,6 +81,17 @@ class API(object):
         for k in kois:
             yield KOI(k)
 
+    def koi(self, koi_number):
+        """
+        Find a single KOI given a KOI number (e.g. 145.01).
+
+        """
+        try:
+            return self.kois(kepoi=koi_number).next()
+        except StopIteration:
+            raise ValueError("No KOI found with the number: '{0}'"
+                             .format(koi_number))
+
     def planets(self, **params):
         """
         Get a list of all the confirmed planets.
@@ -84,6 +105,21 @@ class API(object):
         for p in planets:
             yield Planet(p)
 
+    def planet(self, name):
+        """
+        Get a planet by the Kepler name (e.g. "6b" or "Kepler-62b").
+
+        """
+        matches = re.findall("([0-9]+)[-\s]*([a-zA-Z])", name)
+        if len(matches) != 1:
+            raise ValueError("Invalid planet name '{0}'".format(name))
+        kepler_name = "Kepler-{0} {1}".format(*(matches[0]))
+        try:
+            return self.planets(kepler_name=kepler_name, max_records=1).next()
+        except StopIteration:
+            raise ValueError("No planet found with the name: '{0}'"
+                             .format(kepler_name))
+
     def data(self, kepler_id):
         """
         Get the :class:`bart.kepler.DataList` of observations associated with
@@ -97,7 +133,7 @@ class API(object):
         if data_list is None:
             raise StopIteration()
         for d in data_list:
-            yield Dataset(d)
+            yield _dataset(d)
 
 
 class APIModel(object):
@@ -293,6 +329,11 @@ class KOI(APIModel):
         "Last Update": ("rowupdate", unicode),
     }
 
+    @property
+    def data(self):
+        api = API()
+        return api.data(self.kepid)
+
 
 class Planet(APIModel):
 
@@ -302,7 +343,7 @@ class Planet(APIModel):
         "Kepler ID": ("kepid", int),
         "KOI Name": ("kepoi_name", unicode),
         "Alt Name": ("alt_name", unicode),
-        "KOI Number": ("koi", unicode),
+        "KOI Number": ("koi_number", unicode),  # Just `koi` in API.
         "RA (J2000)": ("degree_ra", float),
         "RA Error": ("ra_err", float),
         "Dec (J2000)": ("degree_dec", float),
@@ -344,8 +385,24 @@ class Planet(APIModel):
         "Last Update": ("koi_vet_date", unicode),
     }
 
+    def __init__(self, *args, **params):
+        super(Planet, self).__init__(*args, **params)
+        self._koi = None
 
-class Dataset(APIModel):
+    @property
+    def data(self):
+        api = API()
+        return api.data(self.kepid)
+
+    @property
+    def koi(self):
+        if self._koi is None:
+            api = API()
+            self._koi = api.koi(self.koi_number)
+        return self._koi
+
+
+class _dataset(APIModel):
 
     _id = "\"{sci_data_set_name}_{ktc_target_type}\""
     _parameters = {
